# encoding: utf-8

require "#{File.expand_path(File.dirname(__FILE__))}/../spec_helper"
require 'logstash/inputs/cloudflare_logs'
require 'pry'

describe LogStash::Inputs::CloudflareLogs do
  describe '#run' do
    before(:each) do
      allow_any_instance_of(LogStash::Inputs::CloudflareLogs).to receive(:process_logs).and_return([])
    end
    it_behaves_like 'an interruptible input plugin' do
      let(:config) { { 'metadata_file' => "#{File.expand_path(File.dirname(__FILE__))}/../tmp/metadata.json", 'interval' => 100, 'auth_email' => 'test@test.com', 'auth_key' => 'test', 'domain_key' => 'asdf' } }
    end
  end

  describe '#process_logs' do
    let(:config) { { 'metadata_file' => "#{File.expand_path(File.dirname(__FILE__))}/../tmp/metadata.json", 'interval' => 100, 'auth_email' => 'test@test.com', 'auth_key' => 'test', 'domain_key' => 'asdf' } }
    let(:queue) { double(:queue, :<< => 'test') }
    before(:each) { allow_any_instance_of(CloudflareAccess).to receive(:logs).and_return([{ a: 1 }]) }
    let(:plugin) { described_class.new(config) }
    subject { plugin.process_logs(queue) }
    before :each do
      event = double(LogStash::Event)
      allow(event).to receive(:timestamp=)
      # allow(LogStash::Event).to receive(:new).and_return(event)
    end

    it 'should create each log event' do
      expect(LogStash::Event).to receive(:new).with(a: 1, 'fields.type' => 'cloudflare', 'fields.env' => nil).and_return(LogStash::Event.new)
      subject
    end

    it 'should create each log event' do
      expect(LogStash::Event).to receive(:new).with(a: 1, 'fields.type' => 'cloudflare', 'fields.env' => nil).and_return(LogStash::Event.new)
      subject
    end

    it 'should decorate the event' do
      expect(plugin).to receive(:decorate).with(instance_of(LogStash::Event))

      subject
    end

    it 'should add the event to the queue' do
      expect(queue).to receive(:<<).with(instance_of(LogStash::Event))

      subject
    end
  end
end
